@@ -109,6 +109,7 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
 
   // cookie store
   private final CookieStore cookieStore;
+  private final int expiredCookieEvictionDelay;
 
   // internals
   private final String threadPoolName;
@@ -133,6 +134,8 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
   private final Consumer<Channel> wsAdditionalChannelInitializer;
   private final ResponseBodyPartFactory responseBodyPartFactory;
   private final int ioThreadsCount;
+  private final long hashedWheelTimerTickDuration;
+  private final int hashedWheelTimerSize;
 
   private DefaultAsyncHttpClientConfig(// http
                                        boolean followRedirect,
@@ -190,6 +193,7 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
 
                                        // cookie store
                                        CookieStore cookieStore,
+                                       int expiredCookieEvictionDelay,
 
                                        // tuning
                                        boolean tcpNoDelay,
@@ -217,7 +221,9 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
                                        Consumer<Channel> httpAdditionalChannelInitializer,
                                        Consumer<Channel> wsAdditionalChannelInitializer,
                                        ResponseBodyPartFactory responseBodyPartFactory,
-                                       int ioThreadsCount) {
+                                       int ioThreadsCount,
+                                       long hashedWheelTimerTickDuration,
+                                       int hashedWheelTimerSize) {
 
     // http
     this.followRedirect = followRedirect;
@@ -279,6 +285,7 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
 
     // cookie store
     this.cookieStore = cookieStore;
+    this.expiredCookieEvictionDelay = expiredCookieEvictionDelay;
 
     // tuning
     this.tcpNoDelay = tcpNoDelay;
@@ -305,6 +312,8 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
     this.wsAdditionalChannelInitializer = wsAdditionalChannelInitializer;
     this.responseBodyPartFactory = responseBodyPartFactory;
     this.ioThreadsCount = ioThreadsCount;
+    this.hashedWheelTimerTickDuration = hashedWheelTimerTickDuration;
+    this.hashedWheelTimerSize = hashedWheelTimerSize;
   }
 
   @Override
@@ -552,6 +561,11 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
     return cookieStore;
   }
 
+  @Override
+  public int expiredCookieEvictionDelay() {
+    return expiredCookieEvictionDelay;
+  }
+
   // tuning
   @Override
   public boolean isTcpNoDelay() {
@@ -639,6 +653,16 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
     return nettyTimer;
   }
 
+  @Override
+  public long getHashedWheelTimerTickDuration() {
+    return hashedWheelTimerTickDuration;
+  }
+
+  @Override
+  public int getHashedWheelTimerSize() {
+    return hashedWheelTimerSize;
+  }
+
   @Override
   public ThreadFactory getThreadFactory() {
     return threadFactory;
@@ -730,6 +754,7 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
 
     // cookie store
     private CookieStore cookieStore = new ThreadSafeCookieStore();
+    private int expiredCookieEvictionDelay = defaultExpiredCookieEvictionDelay();
 
     // tuning
     private boolean tcpNoDelay = defaultTcpNoDelay();
@@ -756,6 +781,8 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
     private Consumer<Channel> wsAdditionalChannelInitializer;
     private ResponseBodyPartFactory responseBodyPartFactory = ResponseBodyPartFactory.EAGER;
     private int ioThreadsCount = defaultIoThreadsCount();
+    private long hashedWheelTickDuration = defaultHashedWheelTimerTickDuration();
+    private int hashedWheelSize = defaultHashedWheelTimerSize();
 
     public Builder() {
     }
@@ -838,6 +865,8 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
       wsAdditionalChannelInitializer = config.getWsAdditionalChannelInitializer();
       responseBodyPartFactory = config.getResponseBodyPartFactory();
       ioThreadsCount = config.getIoThreadsCount();
+      hashedWheelTickDuration = config.getHashedWheelTimerTickDuration();
+      hashedWheelSize = config.getHashedWheelTimerSize();
     }
 
     // http
@@ -1126,6 +1155,11 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
       return this;
     }
 
+    public Builder setExpiredCookieEvictionDelay(int expiredCookieEvictionDelay) {
+      this.expiredCookieEvictionDelay = expiredCookieEvictionDelay;
+      return this;
+    }
+
     // tuning
     public Builder setTcpNoDelay(boolean tcpNoDelay) {
       this.tcpNoDelay = tcpNoDelay;
@@ -1188,6 +1222,16 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
       return this;
     }
 
+    public Builder setHashedWheelTickDuration(long hashedWheelTickDuration) {
+      this.hashedWheelTickDuration = hashedWheelTickDuration;
+      return this;
+    }
+
+    public Builder setHashedWheelSize(int hashedWheelSize) {
+      this.hashedWheelSize = hashedWheelSize;
+      return this;
+    }
+
     @SuppressWarnings("unchecked")
     public <T> Builder addChannelOption(ChannelOption<T> name, T value) {
       channelOptions.put((ChannelOption<Object>) name, value);
@@ -1300,6 +1344,7 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
               responseFilters.isEmpty() ? Collections.emptyList() : Collections.unmodifiableList(responseFilters),
               ioExceptionFilters.isEmpty() ? Collections.emptyList() : Collections.unmodifiableList(ioExceptionFilters),
               cookieStore,
+              expiredCookieEvictionDelay,
               tcpNoDelay,
               soReuseAddress,
               soKeepAlive,
@@ -1323,7 +1368,9 @@ public class DefaultAsyncHttpClientConfig implements AsyncHttpClientConfig {
               httpAdditionalChannelInitializer,
               wsAdditionalChannelInitializer,
               responseBodyPartFactory,
-              ioThreadsCount);
+              ioThreadsCount,
+              hashedWheelTickDuration,
+              hashedWheelSize);
     }
   }
 }
